=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2011-01-25 05:20:15 +0000
+++ drizzled/field.cc	2011-01-26 02:13:21 +0000
@@ -1014,13 +1014,18 @@
 {
   char buff[40];
   String tmp(buff,sizeof(buff),&my_charset_bin),*res;
-  if (!(res=val_str_internal(&tmp)) || str_to_datetime_with_warn(res->ptr(), res->length(),
-                                                                 &ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
+
+  assert(getTable() and getTable()->getSession());
+
+  if (not (res=val_str_internal(&tmp)) or
+      str_to_datetime_with_warn(getTable()->getSession(),
+                                res->ptr(), res->length(),
+                                &ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
   {
-    return 1;
+    return true;
   }
 
-  return 0;
+  return false;
 }
 
 bool Field::get_time(type::Time &ltime)
@@ -1030,10 +1035,10 @@
 
   if (!(res=val_str_internal(&tmp)) || str_to_time_with_warn(res->ptr(), res->length(), &ltime))
   {
-    return 1;
+    return true;
   }
 
-  return 0;
+  return false;
 }
 
 int Field::store_time(type::Time &ltime, type::timestamp_t)
@@ -1200,7 +1205,8 @@
                                  type::timestamp_t ts_type, 
                                  int cuted_increment)
 {
-  Session *session= table ? table->in_use : current_session;
+  Session *session= (getTable() and getTable()->getSession()) ? getTable()->getSession() : current_session;
+
   if ((session->really_abort_on_warning() &&
        level >= DRIZZLE_ERROR::WARN_LEVEL_WARN) ||
       set_warning(level, code, cuted_increment))
@@ -1214,7 +1220,8 @@
                                  type::timestamp_t ts_type,
                                  int cuted_increment)
 {
-  Session *session= table ? table->in_use : current_session;
+  Session *session= (getTable() and getTable()->getSession()) ? getTable()->getSession() : current_session;
+
   if (session->really_abort_on_warning() ||
       set_warning(level, code, cuted_increment))
   {
@@ -1230,7 +1237,8 @@
                                  double nr, 
                                  type::timestamp_t ts_type)
 {
-  Session *session= table ? table->in_use : current_session;
+  Session *session= (getTable() and getTable()->getSession()) ? getTable()->getSession() : current_session;
+
   if (session->really_abort_on_warning() ||
       set_warning(level, code, 1))
   {

=== modified file 'drizzled/field/decimal.cc'
--- drizzled/field/decimal.cc	2011-01-25 00:16:39 +0000
+++ drizzled/field/decimal.cc	2011-01-26 02:13:21 +0000
@@ -152,7 +152,7 @@
   if ((err= decimal_value.store(E_DEC_FATAL_ERROR &
                            ~(E_DEC_OVERFLOW | E_DEC_BAD_NUM),
                            from, length, charset_arg)) &&
-      getTable()->in_use->abort_on_warning)
+      getTable()->in_use->really_abort_on_warning())
   {
     /* Because "from" is not NUL-terminated and we use %s in the ER() */
     String from_as_str;

=== modified file 'drizzled/field/str.cc'
--- drizzled/field/str.cc	2011-01-05 17:21:13 +0000
+++ drizzled/field/str.cc	2011-01-26 02:13:21 +0000
@@ -137,7 +137,7 @@
   length= internal::my_gcvt(nr, internal::MY_GCVT_ARG_DOUBLE, local_char_length, buff, &error);
   if (error)
   {
-    if (getTable()->in_use->abort_on_warning)
+    if (getTable()->getSession()->really_abort_on_warning())
     {
       set_warning(DRIZZLE_ERROR::WARN_LEVEL_ERROR, ER_DATA_TOO_LONG, 1);
     }
@@ -199,7 +199,7 @@
   }
   *t= '\0';
   push_warning_printf(field->getTable()->in_use,
-                      field->getTable()->in_use->abort_on_warning ?
+                      field->getTable()->in_use->really_abort_on_warning() ?
                       DRIZZLE_ERROR::WARN_LEVEL_ERROR :
                       DRIZZLE_ERROR::WARN_LEVEL_WARN,
                       ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2011-01-25 05:20:15 +0000
+++ drizzled/item.cc	2011-01-26 02:13:21 +0000
@@ -474,12 +474,16 @@
 {
   do
   {
-    if (result_type() == STRING_RESULT)
+    if (is_null())
+    {
+      break;
+    }
+    else if (result_type() == STRING_RESULT)
     {
       char buff[40];
       String tmp(buff,sizeof(buff), &my_charset_bin),*res;
       if (!(res=val_str(&tmp)) ||
-          str_to_datetime_with_warn(res->ptr(), res->length(),
+          str_to_datetime_with_warn(current_session, res->ptr(), res->length(),
                                     &ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
       {
         break;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-01-24 04:10:04 +0000
+++ drizzled/session.h	2011-01-26 02:13:21 +0000
@@ -1014,7 +1014,10 @@
   bool substitute_null_with_insert_id;
   bool cleanup_done;
 
+private:
   bool abort_on_warning;
+
+public:
   bool got_warning; /**< Set on call to push_warning() */
   bool no_warnings_for_error; /**< no warnings on call to my_error() */
   /** set during loop of derived table processing */
@@ -1441,7 +1444,17 @@
   /* return true if we will abort query if we make a warning now */
   inline bool really_abort_on_warning()
   {
-    return (abort_on_warning);
+    return abort_on_warning;
+  }
+
+  inline bool abortOnWarning()
+  {
+    return abort_on_warning;
+  }
+
+  inline void setAbortOnWarning(bool arg)
+  {
+    abort_on_warning= arg;
   }
 
   void setAbort(bool arg);

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2011-01-20 14:08:19 +0000
+++ drizzled/sql_insert.cc	2011-01-26 02:13:21 +0000
@@ -281,7 +281,7 @@
       table->cursor->ha_release_auto_increment();
     if (!joins_freed)
       free_underlaid_joins(session, &session->lex->select_lex);
-    session->abort_on_warning= 0;
+    session->setAbortOnWarning(false);
     DRIZZLE_INSERT_DONE(1, 0);
     return true;
   }
@@ -320,7 +320,7 @@
         table->cursor->ha_release_auto_increment();
       if (!joins_freed)
         free_underlaid_joins(session, &session->lex->select_lex);
-      session->abort_on_warning= 0;
+      session->setAbortOnWarning(false);
       DRIZZLE_INSERT_DONE(1, 0);
 
       return true;
@@ -331,7 +331,7 @@
         table->cursor->ha_release_auto_increment();
       if (!joins_freed)
         free_underlaid_joins(session, &session->lex->select_lex);
-      session->abort_on_warning= 0;
+      session->setAbortOnWarning(false);
       DRIZZLE_INSERT_DONE(1, 0);
       return true;
     }
@@ -372,7 +372,7 @@
   }
 
 
-  session->abort_on_warning= !ignore;
+  session->setAbortOnWarning(not ignore);
 
   table->mark_columns_needed_for_insert();
 
@@ -483,7 +483,7 @@
       table->cursor->ha_release_auto_increment();
     if (!joins_freed)
       free_underlaid_joins(session, &session->lex->select_lex);
-    session->abort_on_warning= 0;
+    session->setAbortOnWarning(false);
     DRIZZLE_INSERT_DONE(1, 0);
     return true;
   }
@@ -509,7 +509,7 @@
                    info.copied + info.deleted + info.touched, id, buff);
   }
   session->status_var.inserted_row_count+= session->row_count_func;
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
   DRIZZLE_INSERT_DONE(0, session->row_count_func);
 
   return false;
@@ -610,7 +610,7 @@
     inserting (for INSERT ... SELECT this is done by changing table_list,
     because INSERT ... SELECT share Select_Lex it with SELECT.
   */
-  if (!select_insert)
+  if (not select_insert)
   {
     for (Select_Lex_Unit *un= select_lex->first_inner_unit();
          un;
@@ -658,13 +658,14 @@
 
     if (!res && check_fields)
     {
-      bool saved_abort_on_warning= session->abort_on_warning;
-      session->abort_on_warning= abort_on_warning;
+      bool saved_abort_on_warning= session->abortOnWarning();
+
+      session->setAbortOnWarning(abort_on_warning);
       res= check_that_all_fields_are_given_values(session,
                                                   table ? table :
                                                   context->table_list->table,
                                                   context->table_list);
-      session->abort_on_warning= saved_abort_on_warning;
+      session->setAbortOnWarning(saved_abort_on_warning);
     }
 
     if (!res && duplic == DUP_UPDATE)
@@ -675,17 +676,17 @@
     /* Restore the current context. */
     ctx_state.restore_state(context, table_list);
 
-    if (!res)
+    if (not res)
       res= setup_fields(session, 0, update_values, MARK_COLUMNS_READ, 0, 0);
   }
 
   if (res)
     return(res);
 
-  if (!table)
+  if (not table)
     table= table_list->table;
 
-  if (!select_insert)
+  if (not select_insert)
   {
     TableList *duplicate;
     if ((duplicate= unique_table(table_list, table_list->next_global, true)))
@@ -695,6 +696,7 @@
       return true;
     }
   }
+
   if (duplic == DUP_UPDATE || duplic == DUP_REPLACE)
     table->prepare_for_position();
 
@@ -1014,7 +1016,7 @@
       }
     }
   }
-  return session->abort_on_warning ? err : 0;
+  return session->abortOnWarning() ? err : 0;
 }
 
 /***************************************************************************
@@ -1103,11 +1105,11 @@
 
   if (!res && fields->elements)
   {
-    bool saved_abort_on_warning= session->abort_on_warning;
-    session->abort_on_warning= !info.ignore;
+    bool saved_abort_on_warning= session->abortOnWarning();
+    session->setAbortOnWarning(not info.ignore);
     res= check_that_all_fields_are_given_values(session, table_list->table,
                                                 table_list);
-    session->abort_on_warning= saved_abort_on_warning;
+    session->setAbortOnWarning(saved_abort_on_warning);
   }
 
   if (info.handle_duplicates == DUP_UPDATE && !res)
@@ -1200,13 +1202,17 @@
   table->next_number_field=table->found_next_number_field;
 
   session->cuted_fields=0;
+
   if (info.ignore || info.handle_duplicates != DUP_ERROR)
     table->cursor->extra(HA_EXTRA_IGNORE_DUP_KEY);
+
   if (info.handle_duplicates == DUP_REPLACE)
     table->cursor->extra(HA_EXTRA_WRITE_CAN_REPLACE);
+
   if (info.handle_duplicates == DUP_UPDATE)
     table->cursor->extra(HA_EXTRA_INSERT_WITH_UPDATE);
-  session->abort_on_warning= !info.ignore;
+
+  session->setAbortOnWarning(not info.ignore);
   table->mark_columns_needed_for_insert();
 
 
@@ -1255,7 +1261,7 @@
     table->cursor->ha_reset();
   }
   session->count_cuted_fields= CHECK_FIELD_IGNORE;
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
   return;
 }
 
@@ -1268,14 +1274,14 @@
   if (unit->offset_limit_cnt)
   {						// using limit offset,count
     unit->offset_limit_cnt--;
-    return(0);
+    return false;
   }
 
   session->count_cuted_fields= CHECK_FIELD_WARN;	// Calculate cuted fields
   store_values(values);
   session->count_cuted_fields= CHECK_FIELD_IGNORE;
   if (session->is_error())
-    return(1);
+    return true;
 
   // Release latches in case bulk insert takes a long time
   plugin::TransactionalStorageEngine::releaseTemporaryLatches(session);
@@ -1711,14 +1717,18 @@
   session->cuted_fields=0;
   if (info.ignore || info.handle_duplicates != DUP_ERROR)
     table->cursor->extra(HA_EXTRA_IGNORE_DUP_KEY);
+
   if (info.handle_duplicates == DUP_REPLACE)
     table->cursor->extra(HA_EXTRA_WRITE_CAN_REPLACE);
+
   if (info.handle_duplicates == DUP_UPDATE)
     table->cursor->extra(HA_EXTRA_INSERT_WITH_UPDATE);
+
   table->cursor->ha_start_bulk_insert((ha_rows) 0);
-  session->abort_on_warning= !info.ignore;
+  session->setAbortOnWarning(not info.ignore);
   if (check_that_all_fields_are_given_values(session, table, table_list))
     return(1);
+
   table->mark_columns_needed_for_insert();
   table->cursor->extra(HA_EXTRA_WRITE_CACHE);
   return(0);

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2011-01-16 19:48:25 +0000
+++ drizzled/sql_load.cc	2011-01-26 02:13:21 +0000
@@ -365,7 +365,7 @@
     table->cursor->ha_start_bulk_insert((ha_rows) 0);
     table->copy_blobs=1;
 
-    session->abort_on_warning= true;
+    session->setAbortOnWarning(true);
 
     if (!field_term->length() && !enclosed->length())
       error= read_fixed_length(session, info, table_list, fields_vars,
@@ -414,7 +414,8 @@
               session->transaction.stmt.hasModifiedNonTransData());
   table->cursor->ha_release_auto_increment();
   table->auto_increment_field_not_null= false;
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
+
   return(error);
 }
 

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-01-09 23:01:15 +0000
+++ drizzled/sql_update.cc	2011-01-26 02:13:21 +0000
@@ -454,7 +454,7 @@
   session->set_proc_info("Updating");
 
   transactional_table= table->cursor->has_transactions();
-  session->abort_on_warning= test(!ignore);
+  session->setAbortOnWarning(test(!ignore));
 
   /*
     Assure that we can use position()
@@ -580,7 +580,7 @@
     session->status_var.updated_row_count+= session->row_count_func;
   }
   session->count_cuted_fields= CHECK_FIELD_ERROR_FOR_NULL;		/* calc cuted fields */
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
   DRIZZLE_UPDATE_DONE((error >= 0 || session->is_error()), found, updated);
   return ((error >= 0 || session->is_error()) ? 1 : 0);
 
@@ -595,7 +595,7 @@
     table->key_read=0;
     table->cursor->extra(HA_EXTRA_NO_KEYREAD);
   }
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
 
   DRIZZLE_UPDATE_DONE(1, 0, 0);
   return 1;

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-01-24 21:05:10 +0000
+++ drizzled/statement/alter_table.cc	2011-01-26 02:13:21 +0000
@@ -1480,7 +1480,7 @@
   alter_table_manage_keys(session, to, from->cursor->indexes_are_disabled(), keys_onoff);
 
   /* We can abort alter table for any table type */
-  session->abort_on_warning= !ignore;
+  session->setAbortOnWarning(not ignore);
 
   from->cursor->info(HA_STATUS_VARIABLE | HA_STATUS_NO_LOCK);
   to->cursor->ha_start_bulk_insert(from->cursor->stats.records);
@@ -1644,7 +1644,7 @@
 
   } while (0);
 
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
   from->free_io_cache();
   *copied= found_count;
   *deleted=delete_count;

=== modified file 'drizzled/time_functions.cc'
--- drizzled/time_functions.cc	2011-01-24 22:22:11 +0000
+++ drizzled/time_functions.cc	2011-01-26 02:13:21 +0000
@@ -124,14 +124,14 @@
 }
 
 
-type::timestamp_t str_to_datetime_with_warn(const char *str, 
+type::timestamp_t str_to_datetime_with_warn(Session *session,
+                                            const char *str, 
                                             uint32_t length, 
                                             type::Time *l_time,
                                             uint32_t flags)
 {
   type::cut_t was_cut= type::VALID;
   type::timestamp_t ts_type;
-  Session *session= current_session;
 
   ts_type= l_time->store(str, length,
                          (flags | (session->variables.sql_mode &

=== modified file 'drizzled/time_functions.h'
--- drizzled/time_functions.h	2011-01-17 16:48:48 +0000
+++ drizzled/time_functions.h	2011-01-26 02:13:21 +0000
@@ -73,7 +73,8 @@
   NOTE
     See description of str_to_datetime() for more information.
 */
-type::timestamp_t str_to_datetime_with_warn(const char *str, 
+type::timestamp_t str_to_datetime_with_warn(Session *session,
+                                            const char *str, 
                                             uint32_t length,
                                             type::Time *l_time, 
                                             uint32_t flags);

